@@ -4,12 +4,14 @@ use strict;
 use warnings;
 
 package Perl::PrereqScanner::Scanner::Mojo;
-$Perl::PrereqScanner::Scanner::Mojo::VERSION = '0.2.0';
+$Perl::PrereqScanner::Scanner::Mojo::VERSION = '0.3.0';
 # ABSTRACT: Scan for modules loaded with Mojo::Base
 
 use Moose;
 with 'Perl::PrereqScanner::Scanner';
 
+use PPIx::Literal;
+
 sub scan_for_prereqs {
     my ( $self, $ppi_doc, $req ) = @_;
 
@@ -20,16 +22,12 @@ sub scan_for_prereqs {
         # inheritance
         if ( $self->_is_base_module( $node->module ) ) {
 
+            my @args = PPIx::Literal->convert( $node->arguments );
+
             # skip arguments like '-base', '-strict', '-role', '-signatures'
-            my @meat = grep {
-                     $_->isa('PPI::Token::QuoteLike::Words')
-                  || $_->isa('PPI::Token::Quote')
-                  || $_->isa('PPI::Token::Number')
-            } $node->arguments;
+            @args = grep { !ref && !/^-/ } @args;
 
-            my @args = map { $self->_q_contents($_) } @meat;
-
-            while (@args) {
+            if (@args) {
                 my $module  = shift @args;
                 my $version = '0';
                 $req->add_minimum( $module => $version );
@@ -71,7 +69,7 @@ Perl::PrereqScanner::Scanner::Mojo - Scan for modules loaded with Mojo::Base
 
 =head1 VERSION
 
-version 0.2.0
+version 0.3.0
 
 =head1 SYNOPSIS
 
